package net.pricefx.formulaengine.scripting;

import net.pricefx.server.dto.calculation.DashboardController;
import net.pricefx.server.dto.calculation.ResultMatrix;

/**
 * The constants defined in this interface are typically used as the <code>targetPage</code> parameter when defining
 * links to jump from a dashboard to other parts of the UI. For convenience, the relevant classes will implement
 * this interface, so it can be used as shown below.
 * <br/>
 * Example:
 * <blockquote>
 * <pre>
 * def controller = api.newController()
 * controller.addButton("1. STEP: Go to Live Price Grids", controller.PB_LPG_PAGE, "45.PG", null)
 * // "45.PG" is an optional "targetPageState" parameter
 * // null is an optional "componentId" parameter
 * </pre>
 * </blockquote>
 * The <code>AppPages</code> interface is a default import in the Groovy sandbox, so in the example above you can use
 * either <code>AppPages.PB_LPG_PAGE</code> or <code>controller.PB_LPG_PAGE</code>, both are fine.
 * <p>
 * These constants are confirmed to work in Unity. For potentially deprecated links that used to work in Classic,
 * see <a href="https://pricefx.atlassian.net/wiki/display/HELP/Tokens+for+Page+to+Page+Navigation">Tokens for Page to Page Navigation</a> in the Pricefx
 * Documentation / Configuration Help section.
 * </p>
 * @see DashboardController#addButton(String, String, Object, Object)
 * @see ResultMatrix#linkCell(Object, String, String)
 * @since 7.0 Bijou
 */
@SuppressWarnings("unused")
public interface AppPages {

    // PRICE ANALYZER
    /////////////////

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_PAGE = "dataAnalyzerPage";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_BARLINE_PAGE = "dataAnalyzerPageBarChart";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_BOXPLOT_PAGE = "dataAnalyzerPageBoxplot";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_BUBBLE_PAGE = "dataAnalyzerPageBubble";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_DATATABLE_PAGE = "dataAnalyzerPageDataTable";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_HEATMAP_PAGE = "dataAnalyzerPageHeatmap";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_HISTOGRAM_PAGE = "dataAnalyzerPageHistogram";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_PIE_PAGE = "dataAnalyzerPagePie";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_SCATTER_PAGE = "dataAnalyzerPageScatter";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_TIMESERIES_PAGE = "dataAnalyzerPageTimeSeries";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_DETAILEDTIME_PAGE = "dataAnalyzerPageTimeSeriesDatetime";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_TIMESCATTER_PAGE = "dataAnalyzerPageTimeSeriesScatter";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_WATERFALL_PAGE = "dataAnalyzerPageWaterfall";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_CHART_COMPARISONWF_PAGE = "dataAnalyzerPageWaterfallComparison";

    /**
     * PriceAnalyzer module
     * @since 7.0 Bijou
     */
    String PA_ROLLUPS_PAGE = "paRollupsPage";

    /**
     * PriceAnalyzer module - <code>targetPageState</code> optional <code>typedId</code> for specific DataSource details
     * @since 7.0 Bijou
     */
    String PA_DATASOURCES_PAGE = "dataSourcesPage";


    // DASHBOARDS
    /////////////


    /**
     * Dashboards - <code>targetPageState</code> optional dashboard name
     * @since 7.0 Bijou
     */
    String DB_DASHBOARDS_PAGE = "dashboardPage";


    // MASTER DATA
    //////////////


    /**
     * Master Data - <code>targetPageState</code> optional <code>typedId</code> for specific Product details
     * @since 7.0 Bijou
     */
    String MD_PRODUCTS_PAGE = "productsPage";

    /**
     * Master Data - Product Extensions page
     * @since 7.0 Bijou
     */
    String MD_PX_PAGE = "productExtensionsPage";

    /**
     * Master Data - <code>targetPageState</code> optional <code>typedId</code> for specific Customer details
     * @since 7.0 Bijou
     */
    String MD_CUSTOMERS_PAGE = "customersPage";

    /**
     * Master Data - Customer Extensions page
     * @since 7.0 Bijou
     */
    String MD_CX_PAGE = "customerExtensionsPage";

    /**
     * Master Data - <code>targetPageState</code> optional <code>typedId</code> for specific PricingParameter details
     * @since 7.0 Bijou
     */
    String MD_PP_PAGE = "pricingParametersPage";

    /**
     * Master Data - <code>targetPageState</code> optional <code>typedId</code> for specific Data Change Request details
     * @since 7.0 Bijou
     */
    String MD_DCR_PAGE = "dataChangeRequestPage";

    /**
     * Master Data - Bill of Material page
     * @since 7.0 Bijou
     */
    String MD_BOM_PAGE = "bomPage";

    /**
     * Master Data
     * @since 7.0 Bijou
     */
    String MD_COMPETITION_PAGE = "competitionPage";

    /**
     * Master Data - <code>targetPageState</code> optional <code>typedId</code> for specific Wizard details
     * @since 7.0 Bijou
     */
    String MD_WIZARD_PAGE = "configWizardPage";


    // PRICE BUILDER
    ////////////////

    /**
     * PriceBuilder module - <code>targetPageState</code> optional <code>typedId</code> for specific Price List details
     *
     * @since 7.0 Bijou
     */
    String PB_PL_PAGE = "priceListPage";

    /**
     * PriceBuilder module - Manual Price Lists page
     * @since 7.0 Bijou
     */
    String PB_MPL_PAGE = "manualPriceListPage";

    /**
     * PriceBuilder module - <code>targetPageState</code> optional <code>typedId</code> for specific Live Price Grid details
     * @since 7.0 Bijou
     */
    String PB_LPG_PAGE = "priceGridPage";

    /**
     * PriceBuilder module
     *
     * @since 7.0 Bijou
     */
    String PB_SIMULATION_PAGE = "main_pb_simulationTitle";


    // QUOTE CONFIGURATOR
    /////////////////////


    /**
     * QuoteConfigurator module - <code>targetPageState</code> optional <code>typedId</code> for specific Quote details
     * @since 7.0 Bijou
     */
    String QC_DETAILS_PAGE = "priceShopPage";

    /**
     * QuoteConfigurator module
     * @since 7.0 Bijou
     */
    String QC_TYPES_PAGE = "quoteTypesPage";


    // PROMOTION MANAGER
    ////////////////////


    /**
     * PromotionManager module - <code>targetPageState</code> optional <code>typedId</code> for specific Contract details
     * @since 7.0 Bijou
     */
    String PM_CONTRACTS_PAGE = "contractsPage";


    // REBATE MANAGER
    /////////////////


    /**
     * RebateManager module
     * @since 7.0 Bijou
     */
    String RM_MAIN_PAGE = "main_rebateAgreementsTitle";

    /**
     * RebateManager module - <code>targetPageState</code> optional <code>typedId</code> for specific RebateAgreement details
     * @since 7.0 Bijou
     */
    String RM_DETAILS_PAGE = "rebateAgreementsPage";

    /**
     * RebateManager module - <code>targetPageState</code> optional <code>typedId</code> for specific RebateRecord details
     * @since 7.0 Bijou
     */
    String RM_RECORDS_PAGE = "rebateRecordsPage";

    /**
     * RebateManager module
     * @since 7.0 Bijou
     */
    String RM_TEMPLATES_PAGE = "rebateAgreementsTemplatesPage";


    // CHANNEL MANAGER
    //////////////////


    /**
     * ChannelManager module - <code>targetPageState</code> optional <code>typedId</code> for specific Claim details
     * @since 7.0 Bijou
     */
    String CM_MAIN_PAGE = "claimsPage";

    /**
     * ChannelManager module
     * @since 7.0 Bijou
     */
    String CM_RECORDS_PAGE = "claimRecordsPage";

    /**
     * ChannelManager module
     * @since 7.0 Bijou
     */
    String CM_TYPES_PAGE = "claimTypesPage";


    // PRICE OPTIMIZER - nothing yet ?
    //////////////////


    // DEAL PLANNER
    ///////////////


    /**
     * DealPlanner module - <code>targetPageState</code> optional <code>typedId</code> for specific DealPlan details
     * @since 7.0 Bijou
     */
    String DP_PAGE = "dealPlansPage";

    /**
     * DealPlanner module
     * @since 7.0 Bijou
     */
    String DP_TYPES_PAGE = "dealPlanTypesPage";

    // ADMIN / CONFIG / PREFS
    /////////////////////////


    /**
     * Configuration pages
     * @since 7.0 Bijou
     */
    String CONFIG_WIZARDS_PAGE = "configWizardsPage";

}
